Unfuck Your Habitat | You're better than your mess.

You're better than your mess.

### What’s a 20/10?

Read more

### UfYH Fundamentals

Some key points of the UfYH system.

Read more

### Welcome Packet

Welcome aboard! If you’re new to UfYH, here’s the welcome packet:

Read more

## About UfYH

What is Unfuck Your Habitat? And why should you do it? Well, one of our taglines is: “Terrifying motivation for lazy people with messy homes.” But it’s so much more than that. Yes, it involves some yelling and swearing. But, it’s about motivation, and support, and accountability. Most of the activity happens on our Tumblr site, so if you prefer a more interactive experience, you can visit us there. You’ll see before and after pictures, daily challenges, and questions and answers. If you prefer to explore at your own pace, or can’t figure Tumblr out, stick around here. Your choice.

There’s a weird sort of void in the “taking care of your physical surroundings” stuff, in the archaic “how to keep a home” and “how to be domestic” arenas. It tends to ignore single people, or people without kids, or students, or people with pets, or people with roommates, or people with full-time jobs, or classes, or other shit going on. It assumes everyone is married with kids and one partner is around a lot of the time, and has a lot of time to devote to “housekeeping.”

Well, we don’t all live that life. Very few of us do. Our lives are complicated and sometimes messy, and we’re often distracted and overwhelmed and lazy. Yeah, I said it. We’re lazy. There’s no real shame in that, but it’s something to overcome, at least temporarily. Because no matter what our situations are, we deserve better than to live in filth. We deserve to live somewhere with nice things we love, and to have a clean, calm place to be, when we’re not at work or school or any of the fifty zillion other places we go.

UfYH is gender-neutral. I don’t buy into traditional standards of who “should” be doing cleaning. If you live somewhere, you deserve for that place to be nice and clean and livable, and you should be the one who makes it that way. I don’t care who you are or what box or boxes you check or don’t. I think gender roles as they relate to cleaning (well, in most ways, but that one’s relevant) are bullshit and just offer a handy excuse for half the population to be lazy and the other half to feel guilty.

Fuck that. We’re unfucking traditional gender roles here. Everyone plays.

And our homes aren’t the only things that need to be unfucked. Our finances, our jobs, our relationships: there’s no end to the things we can fuck up. The important thing to remember is that there is nothing that can’t be unfucked. You just have to do it. You just have to overcome the compulsion to sit on the couch, on the computer, watching TV, and get up and do SOMETHING. Anything. So, Unfuck Your Habitat is about lighting a fire under all of our asses. Because when we accomplish something, especially something that seemed impossible, it feels awesome.

If you’re not into it, or not ready to do it, that’s cool. We’ve all been there, where inertia has us almost unable to make changes in our lives. But the whole point of this is that it isn’t hard. It’s almost never hard, and it’s almost never as big of a job as it seems. It’s just a matter of getting started.

So jump in. Don’t worry about catching up. This is about doing what you can, when you can. 5, 10, 20 minutes at a time. And then back to your normal life.

``